@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Annotation;
-$Config::Model::Annotation::VERSION = '2.082';
+$Config::Model::Annotation::VERSION = '2.088';
 use Mouse;
 use English;
 
@@ -16,16 +16,12 @@ use File::Path;
 use IO::File;
 use Data::Dumper;
 
-#use Log::Log4perl qw(get_logger :levels);
-
 use Config::Model::Exception;
 use Config::Model::Node;
 use Config::Model::ObjTreeScanner;
 
-#use strict ;
-use Carp;
-
-#use warnings FATAL => qw(all);
+use strict ;
+use warnings;
 
 use Carp qw/croak confess cluck/;
 
@@ -52,21 +48,6 @@ sub _set_dir {
     return $dir;
 }
 
-#sub new {
-#    my $proto = shift ;
-#    my $class = ref($proto) || $proto ;
-#    my $instance = shift ;
-#
-#    my $self
-#      = {
-#	 instance => $instance ,
-#	};
-#
-#    bless $self, $class;
-#
-#}
-#
-
 sub save {
     my $self = shift;
 
@@ -183,7 +164,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 2.082
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -223,8 +204,8 @@ version 2.082
  $root->fetch_element('baz')->fetch_with_id('en')->annotation('also english') ;
 
  # put more data the easy way
- my $step = 'baz:fr=bonjour#french baz:hr="dobar dan"#croatian';
- $root->load( step => $step ) ;
+ my $steps = 'baz:fr=bonjour#french baz:hr="dobar dan"#croatian';
+ $root->load( steps => $steps ) ;
 
  # dump resulting tree with annotations
  print $root->dump_tree;
@@ -246,7 +227,7 @@ This module provides an object that read and write annotations (a bit
 like comments) to and from a configuration tree and save them in a file (not
 configuration file)
 
-Depending on the effective id of the process, the annotation will be
+Depending on the effective id of the process, the annotation is
 saved in:
 
 =over
