@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::PlainFile;
-$Config::Model::Backend::PlainFile::VERSION = '2.082';
+$Config::Model::Backend::PlainFile::VERSION = '2.088';
 use Carp;
 use Mouse;
 use Config::Model::Exception;
@@ -189,7 +189,7 @@ Config::Model::Backend::PlainFile - Read and write config as plain file
 
 =head1 VERSION
 
-version 2.082
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,7 @@ version 2.082
 
  $inst->write_back ;
 
-Now C</tmp> directory will contain 2 files: C<source> and C<new> 
+Now C</tmp> directory contains 2 files: C<source> and C<new>
 with C<foo> and C<yes> inside.
 
 =head1 DESCRIPTION
@@ -246,7 +246,7 @@ Like L<read_leaf> for list elements.
 
 =head2 write ( )
 
-C<write()> will write a file for each element of the calling class. Works only for 
+C<write()> writes a file for each element of the calling class. Works only for
 leaf and list elements. Other element type are skipped. Always return 1 (unless it died before).
 
 =head1 AUTHOR
