@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::DumpAsData;
-$Config::Model::DumpAsData::VERSION = '2.082';
+$Config::Model::DumpAsData::VERSION = '2.088';
 use Carp;
 use strict;
 use warnings;
@@ -252,7 +252,7 @@ Config::Model::DumpAsData - Dump configuration content as a perl data structure
 
 =head1 VERSION
 
-version 2.082
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -290,8 +290,8 @@ version 2.082
  $root->fetch_element('baz')->fetch_with_id('en')->store('hello') ;
 
  # put more data the easy way
- my $step = 'baz:fr=bonjour baz:hr="dobar dan"';
- $root->load( step => $step ) ;
+ my $steps = 'baz:fr=bonjour baz:hr="dobar dan"';
+ $root->load( steps => $steps ) ;
 
  print Dumper($root->dump_as_data);
  # $VAR1 = {
@@ -310,11 +310,11 @@ This module is used directly by L<Config::Model::Node> to dump the content
 of a configuration tree in perl data structure.
 
 The perl data structure is a hash of hash. Only
-L<CheckList|Config::Model::CheckList> content will be stored in an array ref.
+L<CheckList|Config::Model::CheckList> content is stored in an array ref.
 
 Note that undefined values are skipped for list element. I.e. if a
-list element contains C<('a',undef,'b')>, the data structure will
-contain C<'a','b'>.
+list element contains C<('a',undef,'b')>, the data structure then
+contains C<'a','b'>.
 
 =head1 CONSTRUCTOR
 
@@ -340,7 +340,7 @@ Reference to a L<Config::Model::Node> object. Mandatory
 =item full_dump
 
 Also dump default values in the data structure. Useful if the dumped
-configuration data will be used by the application. (default is yes)
+configuration data is used by the application. (default is yes)
 
 Note that C<mode> parameter is also accepted and overrides
 C<full_dump> parameter. See L<Config::Model::Value/fetch(...)> for
@@ -351,6 +351,12 @@ details on C<mode>.
 Skip node that have a C<perl write> capability in their model. See
 L<Config::Model::BackendMgr>.
 
+This option must be used when using DumpAsData: to write back
+configuration data. When a configuration model contains several
+backends (one at the tree root and others in tree nodes), setting this
+option ensure that the "root" configuration file does not contain data
+duplicated in configuration file of others tree nodes.
+
 =item auto_vivify
 
 Scan and create data for nodes elements even if no actual data was
