@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Exception;
-$Config::Model::Exception::VERSION = '2.082';
+$Config::Model::Exception::VERSION = '2.088';
 use warnings;
 use strict;
 use Data::Dumper;
@@ -75,6 +75,10 @@ sub full_msg_and_trace {
     return $msg;
 }
 
+sub as_string {
+    goto &full_msg_and_trace;
+}
+
 sub full_message {
     my $self = shift;
 
@@ -89,19 +93,19 @@ sub full_message {
 }
 
 package Config::Model::Exception::Any;
-$Config::Model::Exception::Any::VERSION = '2.082';
+$Config::Model::Exception::Any::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception';
 
 package Config::Model::Exception::ModelDeclaration;
-$Config::Model::Exception::ModelDeclaration::VERSION = '2.082';
+$Config::Model::Exception::ModelDeclaration::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
 sub _desc {'configuration model declaration error' }
 
 package Config::Model::Exception::User ;
-$Config::Model::Exception::User::VERSION = '2.082';
+$Config::Model::Exception::User::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 sub _desc {'user error' }
@@ -109,7 +113,7 @@ sub _desc {'user error' }
 
 ## old classes below
 package Config::Model::Exception::Syntax;
-$Config::Model::Exception::Syntax::VERSION = '2.082';
+$Config::Model::Exception::Syntax::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
@@ -130,7 +134,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::LoadData;
-$Config::Model::Exception::LoadData::VERSION = '2.082';
+$Config::Model::Exception::LoadData::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -154,7 +158,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Model;
-$Config::Model::Exception::Model::VERSION = '2.082';
+$Config::Model::Exception::Model::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
@@ -187,7 +191,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::Load;
-$Config::Model::Exception::Load::VERSION = '2.082';
+$Config::Model::Exception::Load::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -216,7 +220,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnavailableElement;
-$Config::Model::Exception::UnavailableElement::VERSION = '2.082';
+$Config::Model::Exception::UnavailableElement::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -247,7 +251,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::AncestorClass;
-$Config::Model::Exception::AncestorClass::VERSION = '2.082';
+$Config::Model::Exception::AncestorClass::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -255,7 +259,7 @@ sub _desc { 'unknown ancestor class'}
 
 
 package Config::Model::Exception::ObsoleteElement;
-$Config::Model::Exception::ObsoleteElement::VERSION = '2.082';
+$Config::Model::Exception::ObsoleteElement::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -280,7 +284,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::UnknownElement;
-$Config::Model::Exception::UnknownElement::VERSION = '2.082';
+$Config::Model::Exception::UnknownElement::VERSION = '2.088';
 use Carp;
 
 use Mouse;
@@ -355,14 +359,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::WarpError;
-$Config::Model::Exception::WarpError::VERSION = '2.082';
+$Config::Model::Exception::WarpError::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'warp error'}
 
 package Config::Model::Exception::Fatal;
-$Config::Model::Exception::Fatal::VERSION = '2.082';
+$Config::Model::Exception::Fatal::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Any';
 
@@ -370,7 +374,7 @@ sub _desc { 'fatal error' }
 
 
 package Config::Model::Exception::UnknownId;
-$Config::Model::Exception::UnknownId::VERSION = '2.082';
+$Config::Model::Exception::UnknownId::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -404,7 +408,7 @@ sub full_message {
 }
 
 package Config::Model::Exception::WrongValue;
-$Config::Model::Exception::WrongValue::VERSION = '2.082';
+$Config::Model::Exception::WrongValue::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -412,7 +416,7 @@ sub _desc { 'wrong value'};
 
 
 package Config::Model::Exception::WrongType;
-$Config::Model::Exception::WrongType::VERSION = '2.082';
+$Config::Model::Exception::WrongType::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
@@ -443,14 +447,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::ConfigFile;
-$Config::Model::Exception::ConfigFile::VERSION = '2.082';
+$Config::Model::Exception::ConfigFile::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::User';
 
 sub _desc { 'error in configuration file' }
 
 package Config::Model::Exception::ConfigFile::Missing;
-$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.082';
+$Config::Model::Exception::ConfigFile::Missing::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::ConfigFile';
 
@@ -467,14 +471,14 @@ sub full_message {
 }
 
 package Config::Model::Exception::Formula;
-$Config::Model::Exception::Formula::VERSION = '2.082';
+$Config::Model::Exception::Formula::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Model';
 
 sub _desc { 'error in computation formula of the configuration model'}
 
 package Config::Model::Exception::Internal;
-$Config::Model::Exception::Internal::VERSION = '2.082';
+$Config::Model::Exception::Internal::VERSION = '2.088';
 use Mouse;
 extends 'Config::Model::Exception::Fatal';
 
@@ -496,7 +500,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.082
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -523,7 +527,7 @@ The exception classes are:
 
 Base class. It accepts an C<object> argument. The user must pass the
 reference of the object where the exception occurred. The object name
-will be used to generate the error message.
+is used to generate the error message.
 
 =back
 
@@ -531,7 +535,7 @@ will be used to generate the error message.
 
 =head1 How to get trace
 
-By default, most of the exceptions will not print out the stack
+By default, most of the exceptions do not print out the stack
 trace. For debug purpose, you can force a stack trace for all
 exception classes:
 
