@@ -8,8 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.086';
+$Config::Model::Instance::VERSION = '2.088';
 #use Scalar::Util qw(weaken) ;
+use strict;
 
 use 5.10.1;
 use Mouse;
@@ -557,7 +558,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.086
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -634,12 +635,28 @@ Specify which backend to use. See L</write_back ( ... )> for details
 
 =item skip_read
 
-DEPRECATED. When set, configuration files will not be read when
+DEPRECATED. When set, configuration files are not read when
 creating configuration tree.
 
 =item check
 
-'yes', 'skip' or 'no'
+Specify whether to check value while reading config files. Either:
+
+=over
+
+=item yes
+
+Check value and throws an error for bad values.
+
+=item skip
+
+Check value and skip bad value.
+
+=item no
+
+Do not check.
+
+=back
 
 =item on_change_cb
 
@@ -649,7 +666,7 @@ arguments: C<< name => <root node element name>, index => <index_value> >>
 =item on_message_cb
 
 Call back this function when L<show_message> is called. By default,
-messages will be displayed on STDOUT.
+messages are displayed on STDOUT.
 
 =item error_paths
 
@@ -662,25 +679,101 @@ Returns a list of error messages from the tree content.
 =back
 
 Note that the root directory specified within the configuration model
-will be overridden by C<root_dir> parameter.
+is overridden by C<root_dir> parameter.
 
 If you need to load configuration data that are not correct, you can
-use C<< force_load => 1 >>. Then, wrong data will be discarded (equivalent to 
+use C<< force_load => 1 >>. Then, wrong data are discarded (equivalent to
 C<check => 'no'> ).
 
 =head1 METHODS
 
+=head2 Manage configuration data
+
+=head2 modify ( ... )
+
+Calls L</"load(...)"> and then L</save>.
+
+Takes the same parameter as C<load> plus C<force_write> to force
+saving configuration file even if no value was modified (default is 0)
+
+=head2 load ( ... )
+
+Load configuration tree with configuration data. See
+L<Config::Model::Loader/"load ( ... )"> for parameters.
+Returns <$self>.
+
+=head2 save ( ... )
+
+Save the content of the configuration tree to
+configuration files. (alias to C<write_back>)
+
+=head2 config_root()
+
+Returns the L<root object|Config::Model::Node> of the configuration tree.
+
+=head2 apply_fixes
+
+Scan the tree and apply fixes that are attached to warning specifications. 
+See C<warn_if_match> or C<warn_unless_match> in L<Config::Model::Value/>.
+
+=head2 needs_save
+
+Returns 1 (or more) if the instance contains data that needs to be
+saved. I.e some change were done in the tree that needs to be saved.
+
+=head2 list_changes
+
+In list context, returns a array ref of strings describing the changes. 
+In scalar context, returns a big string. Useful to print.
+
+=head2 say_changes
+
+Print all changes on STDOUT and return the list of changes.
+
+=head2 has_warning
+
+Returns the number of warning found in the elements of this configuration instance.
+
+=head2 update( quiet => (0|1), %args )
+
+Try to run update command on all nodes of the configuration tree. Node
+without C<update> method are ignored. C<update> prints a message
+otherwise (unless C<quiet> is true).
+
+=head2 searcher ( )
+
+Returns an object dedicated to search an element in the configuration
+model (respecting privilege level).
+
+This method returns a L<Config::Model::Searcher> object. See
+L<Config::Model::Searcher> for details on how to handle a search.
+
+=head2 iterator 
+
+This method returns a L<Config::Model::Iterator> object. See
+L<Config::Model::Iterator> for details.
+
+Arguments are explained in  L<Config::Model::Iterator>
+L<constructor arguments|Config::Model::Iterator/"Creating an iterator">.
+
+=head2 application
+
+Returns the application name of the instance. (E.g C<popcon>, C<dpkg> ...)
+
+=head2 wizard_helper ( ... )
+
+Deprecated. Call L</iterator> instead.
+
+=head1 Internal methods
+
 =head2 name()
 
 Returns the instance name.
 
-=head2 config_root()
-
-Returns the root object of the configuration tree.
-
 =head2 read_check()
 
-Returns how to check read files.
+Returns which kind of check is performed while reading configuration
+files. (see C<check> parameter in L</CONSTRUCTOR> section)
 
 =head2 show_message( string )
 
@@ -744,7 +837,7 @@ Returns 'normal' or 'preset' or 'layered'. Does not take into account initial_lo
 =head2 initial_load_stop ()
 
 Stop initial_load mode. Instance is built with initial_load as 1. Read backend
-will clear this value once the first read is done.
+clears this value once the first read is done.
 
 =head2 initial_load ()
 
@@ -755,40 +848,6 @@ Get initial_load mode
 The data method provide a way to store some arbitrary data in the
 instance object.
 
-=head2 modify ( ... )
-
-Calls L</"load(...)"> and then L</save>.
-
-Takes the same parameter as C<load> plus C<force_write> to force
-saving configuration file even if no value was modified (default is 0)
-
-=head2 load ( ... )
-
-Load configuration tree with configuration data. See
-L<Config::Model::Loader> for more details
-
-=head2 searcher ( )
-
-Returns an object dedicated to search an element in the configuration
-model (respecting privilege level).
-
-This method returns a L<Config::Model::Searcher> object. See
-L<Config::Model::Searcher> for details on how to handle a search.
-
-=head2 wizard_helper ( ... )
-
-Deprecated. Call L</iterator> instead.
-
-=head2 iterator 
-
-This method returns a L<Config::Model::Iterator> object. See
-L<Config::Model::Iterator> for details.
-
-Arguments are explained in  L<Config::Model::Iterator>
-L<constructor arguments|Config::Model::Iterator/"Creating an iterator">.
-
-=head2
-
 =head1 Auto read and write feature
 
 Usually, a program based on config model must first create the
@@ -809,7 +868,7 @@ Returns root directory where configuration data is read from or written to.
 
 =head2 register_write_back ( node_location )
 
-Register a node path that will be called back with
+Register a node path that is called back with
 C<write_back> method.
 
 =head2 notify_change
@@ -817,11 +876,6 @@ C<write_back> method.
 Notify that some data has changed in the tree. See
 L<Config::Model::AnyThing/notify_change(...)> for more details.
 
-=head2 save ( ... )
-
-Save the content of the configuration tree to
-configuration files. (alias to C<write_back>)
-
 =head2 write_back ( ... )
 
 In summary, save the content of the configuration tree to
@@ -834,7 +888,7 @@ for details).
 
 You can specify here a pseudo root directory or another config
 directory to write configuration data back with C<root> and
-C<config_dir> parameters. This will override the model specifications.
+C<config_dir> parameters. This overrides the model specifications.
 
 You can force to use a backend by specifying C<< backend => xxx >>. 
 For instance, C<< backend => 'augeas' >> or C<< backend => 'custom' >>.
@@ -842,36 +896,7 @@ For instance, C<< backend => 'augeas' >> or C<< backend => 'custom' >>.
 You can force to use all backend to write the files by specifying 
 C<< backend => 'all' >>.
 
-C<write_back> will croak if no write call-back are known.
-
-=head2 apply_fixes
-
-Scan the tree and apply fixes that are attached to warning specifications. 
-See C<warn_if_match> or C<warn_unless_match> in L<Config::Model::Value/>.
-
-=head2 needs_save
-
-Returns 1 (or more) if the instance contains data that needs to be
-saved. I.e some change were done in the tree that needs to be saved.
-
-=head2 list_changes
-
-In list context, returns a array ref of strings describing the changes. 
-In scalar context, returns a big string. Useful to print.
-
-=head2 say_changes
-
-Print all changes on STDOUT and return the list of changes.
-
-=head2 has_warning
-
-Returns the number of warning found in the elements of this configuration instance.
-
-=head2 update( quiet => (0|1), %args )
-
-Try to run update command on all nodes of the configuration tree. Node
-without C<update> method are ignored. C<update> will C<say> a message
-otherwise (unless C<quiet> is true).
+C<write_back> croaks if no write call-back are known.
 
 =head1 AUTHOR
 
