@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Node;
-$Config::Model::Node::VERSION = '2.082';
+$Config::Model::Node::VERSION = '2.088';
 use Mouse;
 with "Config::Model::Role::NodeLoader";
 
@@ -481,26 +481,31 @@ sub element_model {
 }
 
 sub element_type {
-    my $self = shift;
-    croak "element_type: missing element name" unless @_;
-    my $element_info = $self->{model}{element}{ $_[0] };
+    my ($self, $name) = @_;
+    croak "element_type: missing element name" unless $name;
+
+    my $element_info = $self->{model}{element}{$name} // $self-> _get_accepted_data($name);
 
     Config::Model::Exception::UnknownElement->throw(
         object   => $self,
         function => 'element_type',
         where    => $self->location || 'configuration root',
-        element  => $_[0],
+        element  => $name,
     ) unless defined $element_info;
 
     return $element_info->{type};
 }
 
 sub get_element_name {
+    goto &get_element_names;
+}
+
+sub get_element_names {
     my $self = shift;
     my %args = @_;
 
     if (delete $args{for}) {
-        carp "get_element_name arg 'for' is deprecated";
+        carp "get_element_names arg 'for' is deprecated";
     }
 
     my $type       = $args{type};              # optional
@@ -536,14 +541,14 @@ sub get_element_name {
         }
     }
 
-    $logger->debug("get_element_name: got @result");
+    $logger->debug("got @result");
 
     return wantarray ? @result : join( ' ', @result );
 }
 
 sub children {
     my $self = shift;
-    return $self->get_element_name;
+    return $self->get_element_names;
 }
 
 sub next_element {
@@ -786,6 +791,17 @@ sub accept_element {
 
     return $model_data->{$name} if defined $model_data->{$name};
 
+    my $acc = $self-> _get_accepted_data($name);
+
+    return $self->reset_accepted_element_model( $name, $acc ) if $acc;
+
+    return;
+}
+
+# return accepted model data or undef
+sub _get_accepted_data {
+    my ( $self, $name ) = @_;
+
     return unless defined $self->{model}{accept};
 
     eval {require Text::Levenshtein::Damerau} ;
@@ -806,10 +822,10 @@ sub accept_element {
 
         }
 
-        my $acc = $self->{model}{accept}{$accept_regexp};
-        return $self->reset_accepted_element_model( $name, $acc );
+        return $self->{model}{accept}{$accept_regexp};
     }
-    return;
+
+    return ;
 }
 
 sub accept_regexp {
@@ -896,14 +912,14 @@ sub load {
     my $self   = shift;
     my $loader = Config::Model::Loader->new;
 
-    my %args = @_ eq 1 ? ( step => $_[0] ) : @_;
-    if ( defined $args{step} ) {
+    my %args = @_ eq 1 ? ( steps => $_[0] ) : @_;
+    if ( defined $args{step} || defined $args{steps}) {
         $loader->load( node => $self, %args );
     }
     else {
         Config::Model::Exception::Load->throw(
             object  => $self,
-            message => "load called with no 'step' parameter",
+            message => "load called with no 'steps' parameter",
         );
     }
 }
@@ -1152,7 +1168,7 @@ Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.082
+version 2.088
 
 =head1 SYNOPSIS
 
@@ -1194,10 +1210,10 @@ version 2.082
  # Z            [undef]      enum         choice: Av Bv Cv
 
  # add some data
- $root->load( step => 'Y=Av' );
+ $root->load( steps => 'Y=Av' );
 
  # add some accepted element, ipA and ipB are created on the fly
- $root->load( step => q!ipA=192.168.1.0 ipB=192.168.1.1"! );
+ $root->load( steps => q!ipA=192.168.1.0 ipB=192.168.1.1"! );
 
  # show also ip* element created in the last "load" call
  print $root->describe,"\n" ;
@@ -1210,7 +1226,7 @@ version 2.082
 =head1 DESCRIPTION
 
 This class provides the nodes of a configuration tree. When created, a
-node object will get a set of rules that will define its properties
+node object gets a set of rules that defines its properties
 within the configuration tree.
 
 Each node contain a set of elements. An element can contain:
@@ -1252,7 +1268,7 @@ element in another configuration class.
 
 =item B<class_description>
 
-Optional C<string> parameter. This description will be used when
+Optional C<string> parameter. This description is used while
 generating user interfaces.
 
 =item B<class>
@@ -1282,8 +1298,8 @@ default value (C<normal>). Possible values are C<important>, C<normal>
 or C<hidden>.
 
 The level is used to set how configuration data is presented to the
-user in browsing mode. C<Important> elements will be shown to the user
-no matter what. C<hidden> elements will be explained with the I<warp>
+user in browsing mode. C<Important> elements are shown to the user
+no matter what. C<hidden> elements are explained with the I<warp>
 notion.
 
   level  => [ [qw/X Y/] => 'important' ]
@@ -1294,21 +1310,20 @@ Optional C<list ref> of the elements whose status are different from
 default value (C<standard>). Possible values are C<obsolete>,
 C<deprecated> or C<standard>.
 
-Using a deprecated element will issue a warning. Using an obsolete
-element will raise an exception (See L<Config::Model::Exception>.
+Using a deprecated element issues a warning. Using an obsolete
+element raises an exception (See L<Config::Model::Exception>.
 
   status  => [ [qw/X Y/] => 'obsolete' ]
 
 =item B<description>
 
-Optional C<list ref> of element description. These descriptions will
-be used when generating user interfaces.
+Optional C<list ref> of element summaries. These summaries may be used
+when generating user interfaces.
 
 =item B<description>
 
-Optional C<list ref> of element summary. These descriptions will be
-used when generating user interfaces or as comment when writing
-configuration files.
+Optional C<list ref> of element descriptions. These descriptions may be
+used when generating user interfaces.
 
 =item B<read_config>
 
@@ -1322,8 +1337,8 @@ See L<Config::Model::BackendMgr> for details.
 =item B<accept>
 
 Optional list of criteria (i.e. a regular expression to match ) to
-accept unknown elements. Each criteria will have a list of
-specification that will enable C<Config::Model> to create a model
+accept unknown elements. Each criteria has a list of
+specification that enable C<Config::Model> to create a model
 snippet for the unknown element.
 
 Example:
@@ -1344,12 +1359,12 @@ Example:
 
 All C<element> parameters can be used in specifying accepted elements.
 
-If L<Text::Levenshtein::Damerau> is installed, a warning will be issued if an accepted
+If L<Text::Levenshtein::Damerau> is installed, a warning is issued if an accepted
 element is too close to an existing element.
 
 The parameter C<accept_after> to specify where to insert the accepted element.
-This will not change much the behavior of the tree, but will help generate
-more usable user interfaces.
+This does not change much the behavior of the tree, but helps generate
+a more usable user interface.
 
 Example:
 
@@ -1364,7 +1379,7 @@ Example:
     }
  ]
 
-The model snippet above will ensure that C<Bug-Debian> will be shown right after C<bug>.
+The model snippet above ensures that C<Bug-Debian> is shown right after C<bug>.
 
 =for html <p>For more information, see <a href="http://ddumont.wordpress.com/2010/05/19/improve-config-upgrade-ep-02-minimal-model-for-opensshs-sshd_config/">this blog</a>.</p>
 
@@ -1522,10 +1537,10 @@ element name must also match the type.
 
 =head2 find_element ( element_name , [ case => any ])
 
-Returns $name if the class model has the element declared or if the element
+Returns C<$name> if the class model has the element declared or if the element
 name is matched by the optional C<accept> parameter.
 
-If case is set to any, has_element will return the element name who match the passed
+If C<case> is set to any, C<has_element> returns the element name who match the passed
 name in a case-insensitive manner.
 
 Returns empty if no matching element is found.
@@ -1547,7 +1562,8 @@ Returns model of the element.
 =head2 element_type ( element_name )
 
 Returns the type (e.g. leaf, hash, list, checklist or node) of the
-element.
+element. Also returns the type of a potentially accepted element.
+Dies if the element is not known or cannot be accepted.
 
 =head2 element_name()
 
@@ -1578,7 +1594,7 @@ configuration file.
 
 =head1 Element property management
 
-=head2 get_element_name (  ...  )
+=head2 get_element_names (  ...  )
 
 Return all elements names available.
 
@@ -1593,11 +1609,11 @@ C<hash>, C<leaf>,...). By default return elements of any type.
 
 =item *
 
-B<cargo_type>: Returns only element which contain requested type.
-E.g. if C<get_element_name> is called with C<< cargo_type => leaf >>,
-C<get_element_name> will return simple leaf elements, but also hash
-or list element that contain L<leaf|Config::Model::Value> object. By
-default return elements of any type.
+B<cargo_type>: Returns only hash or list elements that contain
+the requested cargo type.
+E.g. if C<get_element_names> is called with C<< cargo_type => 'leaf' >>,
+then C<get_element_names> returns hash
+or list elements that contain a L<leaf|Config::Model::Value> object.
 
 =item *
 
@@ -1605,12 +1621,17 @@ B<check>: C<yes>, C<no> or C<skip>
 
 =back
 
-Returns an array in array context, and a string
+C<type> and C<cargo_type> parameters can be specified together. In
+this case, this method returns parameters that satisfy B<both>
+conditions. I.e. with C<< type =>'hash', cargo_type => 'leaf' >>, this
+method returns only hash elements that contain leaf objects.
+
+Returns a list in array context, and a string
 (e.g. C<join(' ',@array)>) in scalar context.
 
 =head2 children
 
-Like get_element_name without parameters. Returns the list of elements. This method is
+Like C<get_element_names> without parameters. Returns the list of elements. This method is
 polymorphic for all non-leaf objects of the configuration tree.
 
 =head2 next_element ( ... )
@@ -1636,7 +1657,7 @@ I.e. for a model :
   status     => [ X => 'deprecated' ]
   element    => [ X => { ... } ]
 
-This call will return C<deprecated>:
+This call returns C<deprecated>:
 
   $node->get_element_property ( element => 'X', property => 'status' )
 
@@ -1679,7 +1700,7 @@ As a syntactic sugar, this method can be called with only one parameter:
 =head2 accept_element( name )
 
 Checks and returns the appropriate model of an acceptable element
-(be it explicitly declared, or part of an C<accept> declaration).
+(i.e. declared as a model C<element> or part of an C<accept> declaration).
 Returns undef if the element cannot be accepted.
 
 =head2 accept_regexp( name )
@@ -1709,8 +1730,8 @@ See L<Config::Model::AnyThing/"grab_root()">.
 
 =head2 get( path => ..., mode => ... ,  check => ... , get_obj => 1|0, autoadd => 1|0)
 
-Get a value from a directory like path. If C<get_obj> is 1, C<get> will return leaf object
-instead of returning their value.
+Get a value from a directory like path. If C<get_obj> is 1, C<get> returns a leaf object
+instead of returning its value.
 
 =head2 set( path  , value)
 
@@ -1728,7 +1749,7 @@ deprecated elements or values. Return 1 if data needs to be saved.
 Scan the tree from this node and apply fixes that are attached to warning specifications.
 See C<warn_if_match> or C<warn_unless_match> in L<Config::Model::Value/>.
 
-=head2 load ( step => string [ ... ])
+=head2 load ( steps => string [ ... ])
 
 Load configuration data from the string into the node and its siblings.
 
@@ -1745,7 +1766,7 @@ Load configuration data with a hash ref. The hash ref key must match
 the available elements of the node (or accepted element). The hash ref structure must match
 the structure of the configuration model.
 
-Use C<< check => skip >> to make data loading more tolerant: bad data will be discarded.
+Use C<< check => skip >> to make data loading more tolerant: bad data are discarded.
 
 C<load_data> can be called with a single hash ref parameter.
 
@@ -1781,7 +1802,7 @@ node.
 =head2 audit ()
 
 Provides a text audit on the content of the configuration below this
-node. This audit will show only value different from their default
+node. This audit shows only value different from their default
 value.
 
 =head2 copy_from ( from => another_node_object, [ check => ... ] )
@@ -1820,7 +1841,8 @@ C<key>, C<summary>, C<description>, C<help> or C<all>.
 
 =back
 
-Typically, you will have to call C<search> on this object.
+Then, C<search> method must then be called on the object returned
+by C<tree_searcher>.
 
 Returns a L<Config::Model::TreeSearcher> object.
 
